@@ -19,6 +19,7 @@ int main(int argc, char** argv)
   Glib::init();
   Gio::init();
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     Glib::RefPtr<Gio::File> file = Gio::File::create_for_path("/etc/fstab");
@@ -30,14 +31,13 @@ int main(int argc, char** argv)
       std::cerr << "Gio::File::read() returned an empty RefPtr." << std::endl;
 
     gchar buffer[1000]; //TODO: This is unpleasant.
-    memset(buffer, 0, 1000);
-    const gsize bytes_read = stream->read(buffer, 1000);
-    
+    memset(buffer, 0, sizeof buffer);
+    const gsize bytes_read = stream->read(buffer, sizeof buffer - 1);
+
     if(bytes_read)
       std::cout << "File contents read: " << buffer << std::endl;
     else
       std::cerr << "Gio::InputStream::read() read 0 bytes." << std::endl;
-
   }
   catch(const Gio::Error& ex)
   {
@@ -55,7 +55,37 @@ int main(int argc, char** argv)
   {
     std::cerr << "Exception caught: " << ex.what() << std::endl; 
   }
+#else /* !GLIBMM_EXCEPTIONS_ENABLED */
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path("/home/murrayc/test.txt");
+  if(!file)
+    std::cerr << "Gio::File::create_for_path() returned an empty RefPtr." << std::endl;
 
+  std::auto_ptr<Glib::Error> error;
+
+  Glib::RefPtr<Gio::FileInputStream> stream = file->read(error);
+  if(!stream)
+    std::cerr << "Gio::File::read() returned an empty RefPtr." << std::endl;
+  if(error.get())
+  {
+    std::cerr << "Exception caught: " << error->what() << std::endl;
+    return 1;
+  }
+
+  gchar buffer[1000]; //TODO: This is unpleasant.
+  memset(buffer, 0, sizeof buffer);
+  const gsize bytes_read = stream->read(buffer, sizeof buffer - 1, error);
+
+  if(bytes_read)
+    std::cout << "File contents read: " << buffer << std::endl;
+  else
+    std::cerr << "Gio::InputStream::read() read 0 bytes." << std::endl;
+
+  if(error.get())
+  {
+    std::cerr << "Exception caught: " << error->what() << std::endl;
+    return 1;
+  }
+#endif /* !GLIBMM_EXCEPTIONS_ENABLED */
 
   return 0;
 }
